==> larus_board-0.8.36.tbz: larus_board-0.8.36/lb_public/lb_ajax_proxy.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board".
 *
 * "Larus Board" is free software: you can redistribute it and/or modify
 * it under the terms of the modified BSD license.
 *
 * "Larus Board" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You should have received a copy of the modified BSD License
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.BSD>.
 */
define('__XF_INCLUDE',1);
require_once('../lb_private/class.root.php');
new XF('ajax');
  if ( XF::vault_query('request_method') !== 'POST' ){
  @ob_end_clean();
  @header('HTTP/1.0 405 Method Not Allowed');
  die('only POST is allowed as "ajax" request!');
  }
XFUI::ajax_init();

function xf__handler($ac,$args){
$purge_used_tan = true;
$action_require_tan = array(
'acp_acl_delete','acp_acl_edit','acp_acl_new','acp_cfg_edit','acp_group_delete','acp_group_edit',
'acp_group_new','acp_pp_delete','acp_pp_edit','acp_pp_new','acp_task_edit','cachemgr','mcp_request',
'post_approve','post_edit','post_edit_revert','post_lock','post_rate','post_reply','post_topic',
'ucp_blacklist','ucp_bookmark','ucp_profile'
);
$user = XF::get_user();
$ac = XF::sanitize_var($ac,'action');
$r = null;
XFUI::$ajax_response = new xajaxResponse();
  if ( XF::DEBUG ){
  XFUI::$ajax_response->alert($ac);
  XFUI::$ajax_response->alert(XF::arr2str($args));
  XFDebug::settracecolor('fff');
  XFDebug::trace(__METHOD__.' {'.$ac.'}',XF::arr2str($args));
  set_error_handler('xf__error');
  }
  if ( (bool)$user['u_login_annoy'] && mt_rand(1,100) < XF::ANNOY_PROBABILITY_ON_AJAX )
  xfaf_failure('{:fun_message_'.mt_rand(1,8).'}');
  else{
    if ( !$ac || defined('__XF_AUTH_IS_TAINTED') || !XF::access_control($ac) )
    xfaf_failure('{:access_denied}');
    else{
      if ( !xf__compare_tan($ac,$args,$action_require_tan) )
      xfaf_failure('{:transaction_number_invalid}');
      else{
        if ( !file_exists(XF::vault_query('root_path').'/action.'.$ac.'.php') )
        xfaf_failure('{:file_not_found}');
        else{
        XF::vault_query('request_action',$ac,'required');
          if ( XF::sql_transaction('is_running:ajax_core') )
          XF::sql_transaction('commit:ajax_core');
        $cn = 'XFAction_'.$ac;
        require_once(XF::vault_query('root_path').'/action.'.$ac.'.php');
          if ( is_subclass_of($cn,'XFAction') ){
          $ao = new $cn();
            if ( isset($ao->version) && (int)$ao->version === XFAction::API_VERSION )
            $r = call_user_func('xfaf_'.$ac,$args);
          unset($ao);
          }
          if ( in_array($ac,$action_require_tan,true) && $r && $purge_used_tan )
          XF::tan($ac,'-');
          if ( XF::sql_transaction('is_running:cleanup') )
          xfaf_failure('{:action_has_not_committed_transaction}');
        }
      }
    }
  }
  if ( !$r )
  XFUI::$ajax_response->call('xf_dosubmit',-1);
  if ( XF::DEBUG ){
  XFDebug::trace(__METHOD__.' {'.$ac.'}',XF::arr2str(array('return'=>$r)));
  XFUI::$ajax_response->assign('xf__ajax_debug','innerHTML',XFDebug::trace(null,'return'));
  }
return XFUI::$ajax_response;
}

function xf__compare_tan($a,&$args,$action_require_tan){
$tan = XF::sanitize_var(XF::ifset($args,'tan',0),'int');
unset($args['tan']);
  if ( in_array($a,$action_require_tan,true) ){
  //D($_SESSION['xf_tan']);
    if ( !isset($_SESSION['xf_tan'][$a]) )
    return false;
  return ( $tan === (int)$_SESSION['xf_tan'][$a] ) ? true : false;
  }
return true;
}

function xf__error($no,$str,$file,$line){
  if ( preg_match('/(\/ext\/|PEAR\.php)/',$file) ) // do not show errors/notices from extensions as there are plenty :)
  return;
  if ( !is_null(XFUI::$ajax_response) ){
  //XFUI::$ajax_response = new xajaxResponse();
    if ( XF::DEBUG )
    XFDebug::trace(__METHOD__,'['.$no.'] '.$str);
  XFUI::$ajax_response->alert('ERROR HANDLER'.chr(10).basename($file).':'.$line.chr(10).$str);
  return XFUI::$ajax_response;
  }
}

function xfaf_process_data($input,$mark){
$rej = array();
  foreach ( $input as $k=>$v ){
    if ( $v === false ){
    $rej[] = $k;
      if ( in_array($k,$mark,true) )
      XFUI::$ajax_response->assign($k,'className','xf_input_invalid');
    }
    else{
      if ( in_array($k,$mark,true) )
      XFUI::$ajax_response->assign($k,'className','xf_input_field');
    }
  }
  // TODO: [low] xfaf_process_data() remove the field names from the following listing (the 'imploded' thing :)
  if ( sizeof($rej) > 0 )
  xfaf_failure(XFUI::i18n('invalid_form_input').'<br />'.implode(', ',$rej));
return ( sizeof($rej) == 0 ) ? true : false;
}

function xfaf_process_input($input,$mark){
$data = XF::validate_gpc_data($input);
xfaf_process_data($data,$mark);
return true;
}

function xfaf_success($uri,$msg){
  if ( substr($msg,0,2) === '{:' )
  $msg = XFUI::lang_str($msg);
  if ( !empty($msg) )
  XFUI::$ajax_response->script("overlib('".$msg."',TIMEOUT,5000,CAPTION,'".XFUI::i18n('success')."',CSSCLASS,BGCLASS,'xf_box_message xf_bm_popup xf_bm_notice',FGCLASS,'xf_transparent',CAPTIONFONTCLASS,'xf_bm_caption',TEXTFONTCLASS,'xf_bm_message');");
  if ( !empty($uri) && !XF::DEBUG )
  XFUI::$ajax_response->redirect(str_replace('&amp;','&',$uri),2);
  if ( XF::DEBUG )
  XFDebug::trace(__METHOD__,$msg);
return true;
}

function xfaf_failure($msg){
  if ( substr($msg,0,2) === '{:' )
  $msg = XFUI::lang_str($msg);
XFUI::$ajax_response->script("overlib('".$msg."',TIMEOUT,5000,CAPTION,'".XFUI::i18n('fail')."',CSSCLASS,BGCLASS,'xf_box_message xf_bm_popup xf_bm_error',FGCLASS,'xf_transparent',CAPTIONFONTCLASS,'xf_bm_caption',TEXTFONTCLASS,'xf_bm_message');");
  if ( XF::DEBUG )
  XFDebug::trace(__METHOD__,$msg);
return false;
}
?>

==> larus_board-0.9.0.tbz: larus_board-0.9.0/lb_public/lb_ajax_proxy.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board".
 *
 * "Larus Board" is free software: you can redistribute it and/or modify
 * it under the terms of the modified BSD license.
 *
 * "Larus Board" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You should have received a copy of the modified BSD License
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.BSD>.
 */
define('__XF_INCLUDE',1);
require_once('../lb_private/class.root.php');
new XF('ajax');
  if ( XF::vault_query('request_method') !== 'POST' ){
  @ob_end_clean();
  @header('HTTP/1.0 405 Method Not Allowed');
  die('only POST is allowed as "ajax" request!');
  }
XFUI::ajax_init();

function xf__handler($ac,$args){
$user = XF::get_user();
$ac = XF::sanitize_var($ac,'action');
$r = null;
XFUI::$ajax_response = new xajaxResponse();
  if ( XF::DEBUG ){
  XFUI::$ajax_response->alert($ac);
  XFUI::$ajax_response->alert(XF::arr2str($args));
  XFDebug::settracecolor('fff');
  XFDebug::trace(__METHOD__.' {'.$ac.'}',XF::arr2str($args));
  set_error_handler('xf__error');
  }
  if ( (bool)$user['u_login_annoy'] && mt_rand(1,100) < XF::ANNOY_PROBABILITY_ON_AJAX )
  xfaf_failure('{:fun_message_'.mt_rand(1,8).'}');
  else{
    if ( !$ac || defined('__XF_AUTH_IS_TAINTED') || !XF::access_control($ac) )
    xfaf_failure('{:access_denied}');
    else{
      if ( !file_exists(XF::vault_query('root_path').'/action.'.$ac.'.php') )
      xfaf_failure('{:file_not_found}');
      else{
      XF::vault_query('request_action',$ac,'required');
        if ( XF::sql_transaction('is_running:ajax_core') )
        XF::sql_transaction('commit:ajax_core');
      $cn = 'XFAction_'.$ac;
      require_once(XF::vault_query('root_path').'/action.'.$ac.'.php');
        if ( is_subclass_of($cn,'XFAction') ){
        $ao = new $cn();
          if ( !xf__compare_tan($ac,$args,constant($cn.'::USE_TAN')) )
          xfaf_failure('{:transaction_number_invalid}');
          else{
            if ( isset($ao->version) && (int)$ao->version === XFAction::API_VERSION )
            $r = call_user_func('xfaf_'.$ac,$args);
          }
        unset($ao);
        }
        if ( constant($cn.'::USE_TAN') === true && $r )
        XF::tan($ac,'-');
        if ( XF::sql_transaction('is_running:cleanup') )
        xfaf_failure('{:action_has_not_committed_transaction}');
      }
    }
  }
  if ( !$r )
  XFUI::$ajax_response->call('xf_dosubmit',-1);
  if ( XF::DEBUG ){
  XFDebug::trace(__METHOD__.' {'.$ac.'}',XF::arr2str(array('return'=>$r)));
  XFUI::$ajax_response->assign('xf__ajax_debug','innerHTML',XFDebug::trace(null,'return'));
  }
return XFUI::$ajax_response;
}

function xf__compare_tan($a,&$args,$action_require_tan){
$tan = XF::sanitize_var(XF::ifset($args,'tan',0),'int');
unset($args['tan']);
  if ( XF::DEBUG )
  return true;
  if ( $action_require_tan ){
    if ( !isset($_SESSION['xf_tan'][$a]) )
    return false;
  return ( $tan === (int)$_SESSION['xf_tan'][$a] ) ? true : false;
  }
return true;
}

function xf__error($no,$str,$file,$line){
  if ( preg_match('/(\/ext\/|PEAR\.php)/',$file) ) // do not show errors/notices from extensions as there are plenty :)
  return;
  if ( !is_null(XFUI::$ajax_response) ){
    if ( XF::DEBUG )
    XFDebug::trace(__METHOD__,'['.$no.'] '.$str);
  XFUI::$ajax_response->alert('ERROR HANDLER'.chr(10).basename($file).':'.$line.chr(10).$str);
  return XFUI::$ajax_response;
  }
}

function xfaf_process_data($input,$mark){
$rej = array();
  foreach ( $input as $k=>$v ){
    if ( $v === false ){
    $rej[] = $k;
      if ( in_array($k,$mark,true) )
      XFUI::$ajax_response->assign($k,'className','xf_input_invalid');
    }
    else{
      if ( in_array($k,$mark,true) )
      XFUI::$ajax_response->assign($k,'className','xf_input_field');
    }
  }
  if ( sizeof($rej) > 0 )
  xfaf_failure(XFUI::i18n('invalid_form_input'));
return ( sizeof($rej) == 0 ) ? true : false;
}

function xfaf_process_input($input,$mark){
$data = XF::validate_gpc_data($input);
xfaf_process_data($data,$mark);
return true;
}

function xfaf_success($uri,$msg){
  if ( substr($msg,0,2) === '{:' )
  $msg = XFUI::lang_str($msg);
  if ( !empty($msg) )
  XFUI::$ajax_response->script("overlib('".$msg."',TIMEOUT,5000,STICKY,CLOSETEXT,'',CAPTION,'".XFUI::i18n('success')."',CSSCLASS,BGCLASS,'xf_box_message xf_bm_popup xf_bm_notice',FGCLASS,'xf_transparent',CAPTIONFONTCLASS,'xf_bm_caption',TEXTFONTCLASS,'xf_bm_message');");
  if ( !empty($uri) && !XF::DEBUG )
  XFUI::$ajax_response->redirect($uri,2);
  if ( XF::DEBUG )
  XFDebug::trace(__METHOD__,$msg);
return true;
}

function xfaf_failure($msg){
  if ( substr($msg,0,2) === '{:' )
  $msg = XFUI::lang_str($msg);
XFUI::$ajax_response->script("overlib('".$msg."',TIMEOUT,5000,STICKY,CLOSETEXT,'',CAPTION,'".XFUI::i18n('fail')."',CSSCLASS,BGCLASS,'xf_box_message xf_bm_popup xf_bm_error',FGCLASS,'xf_transparent',CAPTIONFONTCLASS,'xf_bm_caption',TEXTFONTCLASS,'xf_bm_message');");
  if ( XF::DEBUG )
  XFDebug::trace(__METHOD__,$msg);
return false;
}
?>
